import QtQuick 1.1
import qb.components 1.0

import "stations.js" as StationsJs;

/**
 * Component responsible for displaying province with stations - buttons for selecting the station, circles for station position in province and a link between
 * station and its button.
 * Each province is reusing the same set of WeatherStationElement (button, circle) and Rectangles (lines between circle and button). All elements are
 * stored in arrays in stations.js to be able to iterate and modify all items. For this, init() method has to be called first.
 * The logic to have only one selected WeatherStationElement in a province is also done here.
 */

Item {
	id: root

	property int selectedStationId: -1
	property string selectedStation

	QtObject {
		id: p

		property string lastSelectedProvince
		property int lastSelected: -1
		property int selectedElementId
		property string selectedProvinceName

		property variant diagonalDirection: {
			'rightDown': 1,
			'leftDown': 2,
			'leftUp': 3,
			'rightUp': 4,
		}

		// logic for selecting only one station in a province
		function stationSelected(elementId) {
			if (p.lastSelected === elementId)
				return;

			if (p.lastSelected >= 0) {
				StationsJs.stationElements[p.lastSelected].selected = false;
				for (var i = 0; i < StationsJs.stationElements[p.lastSelected].connectedLinks.length; i++) {
					StationsJs.stationElements[p.lastSelected].connectedLinks[i].selected = false;
				}
			}

			StationsJs.stationElements[elementId].selected = true;
			for (i = 0; i < StationsJs.stationElements[elementId].connectedLinks.length; i++) {
				StationsJs.stationElements[elementId].connectedLinks[i].selected = true;
			}
			p.lastSelected = elementId;
			selectedStationId = StationsJs.stationElements[elementId].stationId;
			selectedStation = StationsJs.stationElements[elementId].stationName;
			p.selectedProvinceName = p.lastSelectedProvince;
			p.selectedElementId = elementId;
		}

		// reset all properties and hide elements
		function hideProvince() {
			for (var i = 0; i < StationsJs.stationElements.length; i++) {
				StationsJs.stationElements[i].visible = false;
				StationsJs.stationElements[i].selected = false;
				StationsJs.stationElements[i].button.anchors.bottom = undefined;
				StationsJs.stationElements[i].button.anchors.top = undefined;
				StationsJs.stationElements[i].button.anchors.verticalCenter = undefined;
				StationsJs.stationElements[i].button.anchors.topMargin = 0;
				StationsJs.stationElements[i].button.anchors.leftMargin = 0;
				StationsJs.stationElements[i].city.anchors.leftMargin = 0;
				StationsJs.stationElements[i].connectedLinks = [];
			}

			for (i = 0; i < StationsJs.stationLinkElement.length; i++) {
				StationsJs.stationLinkElement[i].visible = false;
				StationsJs.stationLinkElement[i].rotation = 0;
				StationsJs.stationLinkElement[i].height = 2;
				StationsJs.stationLinkElement[i].selected = false;
				StationsJs.stationLinkElement[i].shadowPos = StationsJs.stationLinkElement[i].shBottom;
				StationsJs.stationLinkElement[i].setDefaultCorrection();
			}
			p.lastSelected = -1;
		}

		// drawing diagonal (45° angle) from absolut position x,y with length derived from x or y delta (endX - startX is equal to endY - startY)
		// and with direction either rightDown, rightUp, leftDown, leftUp
		function drawDiagonalLine(line, x, y, delta, direction) {
			var startX = 0;
			var startY = 0;
			var rotation = 0;
			if (direction === p.diagonalDirection.rightDown) {
				startX = x;
				startY = y;
				rotation = 45;
			}
			else if (direction === p.diagonalDirection.rightUp) {
				startX = x;
				startY = y;
				rotation = -45;
			}
			else if (direction === p.diagonalDirection.leftDown) {
				startX = x - delta;
				startY = y + delta;
				rotation = -45;
			}
			else if (direction === p.diagonalDirection.leftUp) {
				startX = x - delta;
				startY = y - delta;
				rotation = 45;
			}
			else {
				console.log("drawDiagonalLine: wrong direction: ", direction);
				return;
			}

			line.width = Math.sqrt(2*Math.pow((delta), 2)) + 1;
			line.rotation = rotation;
			line.x = startX;
			line.y = startY;
			line.visible = true;
		}

		// vertical space between 2 elements
		function vSpace(element1, element2) {
			var distance = 0;
			if (element1.y < element2.y)
				distance = element2.y - (element1.y + element1.height);
			else
				distance = element1.y - (element2.y + element2.height);
			return distance;
		}

		// horizontal space between 2 elements
		function hSpace(element1, element2) {
			var distance = 0;
			if (element1.x < element2.x)
				distance = element2.x - (element1.x + element1.width);
			else
				distance = element1.x - (element2.x + element2.width);
			return distance;
		}
	}

	function showProvince(name) {
		p.hideProvince();
		p.lastSelectedProvince = name;
		switch (name) {
			case "gelderland": showGelderland(); break;
			case "noordbrabant": showNoordBrabant(); break;
			case "groningen": showGroningen(); break;
			case "zeeland": showZeeland(); break;
			case "limburg": showLimburg(); break;
			case "zuidholland": showZuidHolland(); break;
			case "noordholland": showNoordHolland(); break;
			case "flevoland": showFlevoland(); break;
			case "overijssel": showOverijssel(); break;
			case "friesland": showFriesland(); break;
			case "drenthe": showDrenthe(); break;
			case "utrecht": showUtrecht(); break;
			default:
				console.log("UNKNOWN PROVINCE NAME!");
				return;
		}

		//if @name is a province where the last selected station is, make the station selected upon showing the province
		if (p.selectedProvinceName === name)
			p.stationSelected(p.selectedElementId);

		provinceImg.source = "../weather/drawables/provincies/" + name + ".png";
	}

	function selectDefault(province, stationId) {
		p.selectedProvinceName = "";
		p.selectedElementId = -1;
		selectedStationId = -1;
		showProvince(province);
		for (var i = 0; i < StationsJs.stationElements.length; i++) {
			if (StationsJs.stationElements[i].stationId === stationId) {
				p.stationSelected(i);
				break;
			}
		}
	}

	function init() {
		StationsJs.stationElements.push(stationElement0);
		StationsJs.stationElements.push(stationElement1);
		StationsJs.stationElements.push(stationElement2);
		StationsJs.stationElements.push(stationElement3);
		StationsJs.stationElements.push(stationElement4);

		StationsJs.stationLinkElement.push(linkElement0);
		StationsJs.stationLinkElement.push(linkElement1);
		StationsJs.stationLinkElement.push(linkElement2);
		StationsJs.stationLinkElement.push(linkElement3);
		StationsJs.stationLinkElement.push(linkElement4);
		StationsJs.stationLinkElement.push(linkElement5);
		StationsJs.stationLinkElement.push(linkElement6);
		StationsJs.stationLinkElement.push(linkElement7);
		StationsJs.stationLinkElement.push(linkElement8);
		StationsJs.stationLinkElement.push(linkElement9);
	}

	function showGelderland() {
		provinceImg.anchors.topMargin = 122;
		provinceImg.anchors.leftMargin = 393;

		stationElement0.stationId = 6283;
		stationElement0.stationName = "Groenlo";
		stationElement0.city.anchors.topMargin = -(179+30+13);
		stationElement0.city.anchors.leftMargin = -(188);
		stationElement0.button.anchors.verticalCenter = stationElement0.city.verticalCenter;
		stationElement0.button.anchors.leftMargin = -(188-28-11);
		stationElement0.button.bottomClickMargin = 8;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = "Groenlo";
		stationElement0.visible = true;
		linkElement0.width = (28+11) - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];


		stationElement1.stationId = 6275;
		stationElement1.stationName = "Arnhem";
		stationElement1.city.anchors.topMargin = -(179);
		stationElement1.city.anchors.leftMargin = -(188+101);
		stationElement1.button.anchors.top = stationElement1.city.top;
		stationElement1.button.anchors.leftMargin = -(188-28-11);
		stationElement1.button.topClickMargin = 8;
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.button.text = "Arnhem";
		stationElement1.visible = true;
		linkElement1.width = (101+28) - stationElement1.city.width;
		linkElement1.x = stationElement1.city.x + 15;
		linkElement1.y = stationElement1.city.y + 7;
		linkElement1.visible = true;
		p.drawDiagonalLine(linkElement2, linkElement1.x + linkElement1.width - 1, linkElement1.y, 11 + 1, p.diagonalDirection.rightDown);
		linkElement2.setCorrection(1, 0, 0, 0, 0, -1, 0, 1);
		stationElement1.connectedLinks = [linkElement1, linkElement2];

		stationElement3.visible = false;
		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showNoordBrabant() {
		provinceImg.anchors.topMargin = 160;
		provinceImg.anchors.leftMargin = 411;

		stationElement0.stationId = 6350;
		stationElement0.stationName = "Gilze Rijen";
		stationElement0.city.anchors.topMargin = -(149+33+9+30);
		stationElement0.city.anchors.leftMargin = -(96+37+70+17+66);
		stationElement0.button.anchors.top = stationElement0.bottom
		stationElement0.button.anchors.topMargin = -(149+33+9+30+18+11+35);
		stationElement0.button.anchors.leftMargin = -(96+37+70+17+66+17+67);
		stationElement0.button.bottomClickMargin = 10;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = "Gilze Rijen";
		stationElement0.visible = true;
		linkElement0.width = 18;
		linkElement0.x = stationElement0.city.x - 18 + 1;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.setCorrection(-1, 0, 1, 0, -1, 0, 1, 0);
		linkElement0.visible = true;
		p.drawDiagonalLine(linkElement1, stationElement0.city.x - 18 + 1, stationElement0.city.y + 7, p.vSpace(stationElement0.button, linkElement0) + 1, p.diagonalDirection.leftUp);
		linkElement1.setCorrection(0, 0, 1, 0, 0, 0, -1, 0);
		stationElement0.connectedLinks = [linkElement0, linkElement1];

		stationElement1.stationId = 6340;
		stationElement1.stationName = "Woensdrecht";
		stationElement1.city.anchors.topMargin = -(149+33);
		stationElement1.city.anchors.leftMargin = -(96+37+70+17+66+18+67);
		stationElement1.button.anchors.top = stationElement1.bottom;
		stationElement1.button.anchors.topMargin = -149;
		stationElement1.button.anchors.leftMargin = -(96+37+70+17+66+18+67+19);
		stationElement1.button.text = qsTr("Woensdrecht");
		stationElement1.button.topClickMargin = 10;
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.visible = true;
		linkElement2.height = 33 - stationElement1.city.height;
		linkElement2.width = 2;
		linkElement2.x = stationElement1.city.x + 7;
		linkElement2.y = stationElement1.city.y + 15;
		linkElement2.visible = true;
		linkElement2.shadowPos = linkElement2.shRight;
		linkElement2.setVerticalCorrection();
		stationElement1.connectedLinks = [linkElement2];

		stationElement2.stationId = 6375;
		stationElement2.stationName = "Volkel";
		stationElement2.city.anchors.topMargin = -(149+33+9+30+18);
		stationElement2.city.anchors.leftMargin = -(96+37+70);
		stationElement2.button.anchors.verticalCenter = stationElement2.city.verticalCenter;
		stationElement2.button.anchors.leftMargin = -96;
		stationElement2.button.topClickMargin = 10;
		stationElement2.button.bottomClickMargin = 10;
		stationElement2.button.text = "Volkel";
		stationElement2.visible = true;
		linkElement3.width = (70+37) - stationElement2.city.width;
		linkElement3.x = stationElement2.city.x + 15;
		linkElement3.y = stationElement2.city.y + 7;
		linkElement3.visible = true;
		stationElement2.connectedLinks = [linkElement3];

		stationElement3.stationId = 6370;
		stationElement3.stationName = "Eindhoven";
		stationElement3.city.anchors.topMargin = -(149+33);
		stationElement3.city.anchors.leftMargin = -(96+37+70+17);
		stationElement3.button.anchors.verticalCenter = stationElement3.city.verticalCenter;
		stationElement3.button.anchors.leftMargin = -(96+37);
		stationElement3.button.topClickMargin = 10;
		stationElement3.button.text = qsTr("Eindhoven");
		stationElement3.button.topClickMargin = 10;
		stationElement3.button.bottomClickMargin = 10;
		stationElement3.visible = true;
		linkElement4.width = (70+17) - stationElement3.city.width;
		linkElement4.x = stationElement3.city.x + 15;
		linkElement4.y = stationElement3.city.y + 7;
		linkElement4.visible = true;
		stationElement3.connectedLinks = [linkElement4];

		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showGroningen() {
		provinceImg.anchors.topMargin = 144;
		provinceImg.anchors.leftMargin = 455;

		stationElement0.stationId = 6277;
		stationElement0.stationName = "Lauwersoog";
		stationElement0.city.anchors.topMargin = -(171+25+23+5+12+31);
		stationElement0.city.anchors.leftMargin = -(159+44+7+87+36);
		stationElement0.button.anchors.top = stationElement0.bottom
		stationElement0.button.anchors.topMargin = -(171+25+23+5+12+31+11);
		stationElement0.button.anchors.leftMargin = -(159);
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.bottomClickMargin = 10;
		stationElement0.button.text = "Lauwersoog";
		stationElement0.visible = true;
		linkElement0.width = (44+7+87+36) - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];

		stationElement1.stationId = 6280;
		stationElement1.stationName = "Groningen";
		stationElement1.city.anchors.topMargin = -(171+25+23+5);
		stationElement1.city.anchors.leftMargin = -(159+44+7+87);
		stationElement1.button.anchors.top = stationElement1.bottom;
		stationElement1.button.anchors.topMargin = -(171+25+23+5+12);
		stationElement1.button.anchors.leftMargin = -(159+44+7+87+36+69);
		stationElement1.button.topClickMargin = 10;
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.button.text = qsTr("Groningen");
		stationElement1.visible = true;
		linkElement1.x = stationElement1.button.x + stationElement1.button.width;
		linkElement1.y = stationElement1.city.y + 7;
		linkElement1.width = stationElement1.city.x - linkElement1.x;
		linkElement1.setCorrection(0, 0, 1, 0, 0, 0, 0, 0);
		linkElement1.visible = true;
		stationElement1.connectedLinks = [linkElement1];

		stationElement2.stationId = 6286;
		stationElement2.stationName = "Nieuw Beerta";
		stationElement2.city.anchors.topMargin = -(171+25+23);
		stationElement2.city.anchors.leftMargin = -(159+44+7);
		stationElement2.button.anchors.top = stationElement2.bottom;
		stationElement2.button.anchors.topMargin = -(171);
		stationElement2.button.anchors.leftMargin = -(159);
		stationElement2.button.topClickMargin = 10;
		stationElement2.button.bottomClickMargin = 10;
		stationElement2.button.text = "Nieuw Beerta";
		stationElement2.visible = true;
		linkElement2.width = 2;
		linkElement2.height = 23 - stationElement2.city.height;
		linkElement2.x = stationElement2.city.x + 7;
		linkElement2.y = stationElement2.city.y + 15;
		linkElement2.shadowPos = linkElement2.shLeft;
		linkElement2.setCorrection(0, -1, 0, 3, 0, -1, 0, -1);
		linkElement2.visible = true;
		p.drawDiagonalLine(linkElement3, stationElement2.city.x + 7 + 1, stationElement2.city.y + 23, 44, p.diagonalDirection.rightDown);
		linkElement3.setCorrection(0, 0, 0, 0, 2, 0, -2, 0);
		stationElement2.connectedLinks = [linkElement2, linkElement3];

		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showZeeland(province) {
		provinceImg.anchors.topMargin = 142;
		provinceImg.anchors.leftMargin = 432;

		/* Removed from data set
		stationElement0.stationId = 6323;
		stationElement0.stationName = "Goes";
		stationElement0.city.anchors.topMargin = -(166+9+33+7+7);
		stationElement0.city.anchors.leftMargin = -(147+29+112);
		stationElement0.button.anchors.top = stationElement0.bottom
		stationElement0.button.anchors.topMargin = -(166+9+33+7+7+38);
		stationElement0.button.anchors.leftMargin = -147;
		stationElement0.button.text = qsTr("Goes");
		stationElement0.visible = true;
		linkElement0.width = 112 - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		p.drawDiagonalLine(linkElement1, linkElement0.x + linkElement0.width - 1, linkElement0.y, 29, p.diagonalDirection.rightUp);
		*/

		stationElement1.stationId = 6310;
		stationElement1.stationName = "Vlissingen";
		stationElement1.city.anchors.topMargin = -(166+9+33);
		stationElement1.city.anchors.leftMargin = -(147+29+112+3+53);
		stationElement1.button.anchors.verticalCenter = stationElement1.city.verticalCenter;
		stationElement1.button.anchors.leftMargin = -147;
		stationElement1.button.text = qsTr("Vlissingen");
		stationElement1.button.bottomClickMargin = 2;
		stationElement1.button.topClickMargin = 10;
		stationElement1.visible = true;
		linkElement2.width = 29+112+3+53 - stationElement0.city.width;
		linkElement2.x = stationElement1.city.x + 15;
		linkElement2.y = stationElement1.city.y + 7;
		linkElement2.visible = true;
		stationElement1.connectedLinks = [linkElement2];

		stationElement2.stationId = 6319;
		stationElement2.stationName = "Westdorpe";
		stationElement2.city.anchors.topMargin = -(166);
		stationElement2.city.anchors.leftMargin = -(147+29+112+3);
		stationElement2.button.anchors.verticalCenter = stationElement2.city.verticalCenter;
		stationElement2.button.anchors.leftMargin = -147;
		stationElement2.button.text = "Westdorpe";
		stationElement2.button.bottomClickMargin = 10;
		stationElement2.button.topClickMargin = 3;
		stationElement2.visible = true;
		linkElement3.width = 29+112+3 - stationElement0.city.width;
		linkElement3.x = stationElement2.city.x + 15;
		linkElement3.y = stationElement2.city.y + 7;
		linkElement3.visible = true;
		stationElement2.connectedLinks = [linkElement3];

		stationElement3.visible = false;
		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showLimburg() {
		provinceImg.anchors.topMargin = 127;
		provinceImg.anchors.leftMargin = 456;

		stationElement0.stationId = 6391;
		stationElement0.stationName = "Arcen";
		stationElement0.city.anchors.topMargin = -(136+12+65+7+28);
		stationElement0.city.anchors.leftMargin = -(145+159);
		stationElement0.button.anchors.top = stationElement0.bottom;
		stationElement0.button.anchors.topMargin = -(136+12+65+7+28+12);
		stationElement0.button.anchors.leftMargin = -145;
		stationElement0.button.bottomClickMargin = 2;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = "Arcen";
		stationElement0.visible = true;
		linkElement0.width = 159 - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];


		stationElement1.stationId = 6377;
		stationElement1.stationName = "Ell";
		stationElement1.city.anchors.topMargin = -(136+12+65);
		stationElement1.city.anchors.leftMargin = -(145+159+32);
		stationElement1.button.anchors.top = stationElement1.bottom;
		stationElement1.button.anchors.topMargin = -(136+12+65+7);
		stationElement1.button.anchors.leftMargin = -145;
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.button.topClickMargin = 2;
		stationElement1.button.text = "Ell";
		stationElement1.visible = true;
		linkElement1.width = (32+159) - stationElement1.city.width;
		linkElement1.x = stationElement1.city.x + 15;
		linkElement1.y = stationElement1.city.y + 7;
		linkElement1.visible = true;
		stationElement1.connectedLinks = [linkElement1];

		stationElement2.stationId = 6380;
		stationElement2.stationName = "Maastricht";
		stationElement2.city.anchors.topMargin = -(136);
		stationElement2.city.anchors.leftMargin = -(145+159+32+4);
		stationElement2.button.anchors.top = stationElement2.bottom;
		stationElement2.button.anchors.topMargin = -(136+12);
		stationElement2.button.anchors.leftMargin = -145;
		stationElement2.button.bottomClickMargin = 10;
		stationElement2.button.topClickMargin = 10;
		stationElement2.button.text = qsTr("Maastricht");
		stationElement2.visible = true;
		linkElement2.width = (4+32+159) - stationElement2.city.width;
		linkElement2.x = stationElement2.city.x + 15;
		linkElement2.y = stationElement2.city.y + 7;
		linkElement2.visible = true;
		stationElement2.connectedLinks = [linkElement2];

		stationElement3.visible = false;
		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showZuidHolland() {
		provinceImg.anchors.topMargin = 130;
		provinceImg.anchors.leftMargin = 473;

/*removed		stationElement0.stationId = 6210;
		stationElement0.stationName = "Katwijk";
		stationElement0.city.anchors.topMargin = -(150+7+25+3+7+44);
		stationElement0.city.anchors.leftMargin = -(120+45+88);
		stationElement0.button.anchors.top = stationElement0.bottom
		stationElement0.button.anchors.topMargin = -(150+7+25+3+7+44+6+5);
		stationElement0.button.anchors.leftMargin = -(120);
		stationElement0.button.bottomClickMargin = 9;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = qsTr("Katwijk");
		stationElement0.visible = true;
		linkElement0.width = (88+45) - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];
*/
		stationElement1.stationId = 6330;
		stationElement1.stationName = "Hoek v Holland";
		stationElement1.city.anchors.topMargin = -(150+7+25+3);
		stationElement1.city.anchors.leftMargin = -(120+45+88+40);
		stationElement1.button.anchors.top = stationElement1.bottom;
		stationElement1.button.anchors.topMargin = -(150+7+25+3+7+44+6+5+41);
		stationElement1.button.anchors.leftMargin = -(120+45+88+40+99);
		stationElement1.button.text = qsTr("Hoek van Holland");
		stationElement1.button.bottomClickMargin = 5;
		stationElement1.button.topClickMargin = 10;
		stationElement1.visible = true;
		linkElement1.width = 2;
		linkElement1.height = stationElement1.city.y - (stationElement1.button.y + stationElement1.button.height);
		linkElement1.y = (stationElement1.button.y + stationElement1.button.height);
		linkElement1.x = stationElement1.city.x + 7;
		linkElement1.setCorrection(0, 0, 0, 1, 0, 0, 0, 0);
		linkElement1.shadowPos = linkElement1.shRight;
		linkElement1.visible = true;
		stationElement1.connectedLinks = [linkElement1];

		stationElement2.stationId = 6356;
		stationElement2.stationName = "Herwijnen";
		stationElement2.city.anchors.topMargin = -(150+7+25);
		stationElement2.city.anchors.leftMargin = -(120+45);
		stationElement2.button.anchors.top = stationElement2.bottom;
		stationElement2.button.anchors.topMargin = -(150+7+25+3+7);
		stationElement2.button.anchors.leftMargin = -120;
		stationElement2.button.bottomClickMargin = 10;
		stationElement2.button.topClickMargin = 10;
		stationElement2.button.text = "Herwijnen";
		stationElement2.visible = true;
		linkElement2.width = (45) - stationElement2.city.width;
		linkElement2.x = stationElement2.city.x + 15;
		linkElement2.y = stationElement2.city.y + 7;
		linkElement2.visible = true;
		stationElement2.connectedLinks = [linkElement2];

		stationElement3.stationId = 6344;
		stationElement3.stationName = "Rotterdam";
		stationElement3.city.anchors.topMargin = -(150+7);
		stationElement3.city.anchors.leftMargin = -(120+45+88);
		stationElement3.button.anchors.top = stationElement3.bottom;
		stationElement3.button.anchors.topMargin = -(150+7+25+3+7+44+6);
		stationElement3.button.anchors.leftMargin = -(120+45+88+40+99);
		stationElement3.button.bottomClickMargin = 10;
		stationElement3.button.topClickMargin = 5;
		stationElement3.button.text = qsTr("Rotterdam");
		stationElement3.visible = true;
		linkElement3.width = 40;
		linkElement3.x = stationElement3.city.x - linkElement3.width;
		linkElement3.y = stationElement3.city.y + 7;
		linkElement3.setCorrection(-1, 0, 2, 0, 0, 0, -1, 0);
		linkElement3.visible = true;
		p.drawDiagonalLine(linkElement4, stationElement3.city.x - 40 + 1, stationElement3.city.y + 7, p.vSpace(linkElement3, stationElement3.button) + 1, p.diagonalDirection.leftUp);
		linkElement4.clearCorrection();
		stationElement3.connectedLinks = [linkElement3, linkElement4];

		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showNoordHolland() {
		provinceImg.anchors.topMargin = 126;
		provinceImg.anchors.leftMargin = 461;

		stationElement0.stationId = 6235;
		stationElement0.stationName = "Den_Helder";
		stationElement0.city.anchors.topMargin = -(138+11+62+10+38);
		stationElement0.city.anchors.leftMargin = -(154+137+29+3);
		stationElement0.button.anchors.top = stationElement0.bottom;
		stationElement0.button.anchors.topMargin = -(138+11+62+10+38+11);
		stationElement0.button.anchors.leftMargin = -154;
		stationElement0.button.bottomClickMargin = 6;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = qsTr("Den Helder");
		stationElement0.visible = true;
		linkElement0.width = (3+29+137) - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];


		stationElement1.stationId = 6249;
		stationElement1.stationName = "Berkhout";
		stationElement1.city.anchors.topMargin = -(138+11+62);
		stationElement1.city.anchors.leftMargin = -(154+137);
		stationElement1.button.anchors.top = stationElement1.bottom;
		stationElement1.button.anchors.topMargin = -(138+11+62+10);
		stationElement1.button.anchors.leftMargin = -154;
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.button.topClickMargin = 6;
		stationElement1.button.text = qsTr("Berkhout");
		stationElement1.visible = true;
		linkElement1.width = (137) - stationElement1.city.width;
		linkElement1.x = stationElement1.city.x + 15;
		linkElement1.y = stationElement1.city.y + 7;
		linkElement1.visible = true;
		stationElement1.connectedLinks = [linkElement1];

		stationElement2.stationId = 6240;
		stationElement2.stationName = "Schiphol";
		stationElement2.city.anchors.topMargin = -(138);
		stationElement2.city.anchors.leftMargin = -(154+137+29);
		stationElement2.button.anchors.top = stationElement2.bottom;
		stationElement2.button.anchors.topMargin = -(138+11);
		stationElement2.button.anchors.leftMargin = -154;
		stationElement2.button.bottomClickMargin = 10;
		stationElement2.button.topClickMargin = 10;
		stationElement2.button.text = "Schiphol";
		stationElement2.visible = true;
		linkElement2.width = (29+137) - stationElement2.city.width;
		linkElement2.x = stationElement2.city.x + 15;
		linkElement2.y = stationElement2.city.y + 7;
		linkElement2.visible = true;
		stationElement2.connectedLinks = [linkElement2];

		stationElement3.visible = false;
		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showFlevoland() {
		provinceImg.anchors.topMargin = 130;
		provinceImg.anchors.leftMargin = 414;

		stationElement0.stationId = 6273;
		stationElement0.stationName = "Marknesse";
		stationElement0.city.anchors.topMargin = -(189+10+65);
		stationElement0.city.anchors.leftMargin = -(166+98);
		stationElement0.button.anchors.verticalCenter = stationElement0.city.verticalCenter;
		stationElement0.button.anchors.leftMargin = -166;
		stationElement0.button.bottomClickMargin = 10;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = "Marknesse";
		stationElement0.visible = true;
		linkElement0.width = 98 - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];


		stationElement1.stationId = 6269;
		stationElement1.stationName = "Lelystad";
		stationElement1.city.anchors.topMargin = -(189+10);
		stationElement1.city.anchors.leftMargin = -(166+98+56);
		stationElement1.button.anchors.verticalCenter = stationElement1.city.verticalCenter;
		stationElement1.button.anchors.leftMargin = -166;
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.button.topClickMargin = 10;
		stationElement1.button.text = qsTr("Lelystad");
		stationElement1.visible = true;
		linkElement1.width = (98+56) - stationElement1.city.width;
		linkElement1.x = stationElement1.city.x + 15;
		linkElement1.y = stationElement1.city.y + 7;
		linkElement1.visible = true;
		stationElement1.connectedLinks = [linkElement1];

		stationElement2.visible = false;
		stationElement3.visible = false;
		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showOverijssel() {
		provinceImg.anchors.topMargin = 132;
		provinceImg.anchors.leftMargin = 415;

		stationElement0.stationId = 6278;
		stationElement0.stationName = "Heino";
		stationElement0.city.anchors.topMargin = -(151+10+60);
		stationElement0.city.anchors.leftMargin = -(146+94+106);
		stationElement0.button.anchors.top = stationElement0.bottom;
		stationElement0.button.anchors.topMargin = -(151+10+60+9);
		stationElement0.button.anchors.leftMargin = -146;
		stationElement0.button.bottomClickMargin = 10;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = "Heino";
		stationElement0.visible = true;
		linkElement0.width = (106+94) - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];

		stationElement1.stationId = 6290;
		stationElement1.stationName = "Twente";
		stationElement1.city.anchors.topMargin = -(151);
		stationElement1.city.anchors.leftMargin = -(146+94);
		stationElement1.button.anchors.top = stationElement1.bottom;
		stationElement1.button.anchors.topMargin = -(151+10);
		stationElement1.button.anchors.leftMargin = -146;
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.button.topClickMargin = 10;
		stationElement1.button.text = qsTr("Twente");
		stationElement1.visible = true;
		linkElement1.width = (94) - stationElement1.city.width;
		linkElement1.x = stationElement1.city.x + 15;
		linkElement1.y = stationElement1.city.y + 7;
		linkElement1.visible = true;
		stationElement1.connectedLinks = [linkElement1];

		stationElement2.visible = false;
		stationElement3.visible = false;
		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showDrenthe() {
		provinceImg.anchors.topMargin = 128;
		provinceImg.anchors.leftMargin = 407;

		stationElement0.stationId = 6279;
		stationElement0.stationName = "Hoogeveen";
		stationElement0.city.anchors.topMargin = -(166);
		stationElement0.city.anchors.leftMargin = -(146+189);
		stationElement0.button.anchors.top = stationElement0.bottom;
		stationElement0.button.anchors.topMargin = -(166+10);
		stationElement0.button.anchors.leftMargin = -146;
		stationElement0.button.bottomClickMargin = 10;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = qsTr("Hoogeveen");
		stationElement0.visible = true;
		linkElement0.width = (189) - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];

		stationElement1.visible = false;
		stationElement2.visible = false;
		stationElement3.visible = false;
		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showFriesland() {
		provinceImg.anchors.topMargin = 137;
		provinceImg.anchors.leftMargin = 426;

		stationElement0.stationId = 6251;
		stationElement0.stationName = "Terschelling";
		stationElement0.city.anchors.topMargin = -(166+9+54+7+4+26);
		stationElement0.city.anchors.leftMargin = -(155+17+90+44+23);
		stationElement0.button.anchors.top = stationElement0.bottom;
		stationElement0.button.anchors.topMargin = -(166+9+54+7+4+26+10);
		stationElement0.button.anchors.leftMargin = -155;
		stationElement0.button.bottomClickMargin = 5;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = qsTr("Terschelling");
		stationElement0.visible = true;
		linkElement0.width = (23+44+90+17) - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];

		stationElement1.stationId = 6242;
		stationElement1.stationName = "Vlieland";
		stationElement1.city.anchors.topMargin = -(166+9+54+7+4);
		stationElement1.city.anchors.leftMargin = -(155+17+90+44+23+35);
		stationElement1.button.anchors.top = stationElement1.bottom;
		stationElement1.button.anchors.topMargin = -(166);
		stationElement1.button.anchors.leftMargin = -(155+17+90+44+23+35+31);
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.button.topClickMargin = 10;
		stationElement1.button.text = qsTr("Vlieland");
		stationElement1.visible = true;
		linkElement1.height = stationElement1.button.y - (stationElement1.city.y + stationElement1.city.height);
		linkElement1.width = 2;
		linkElement1.x = stationElement1.city.x + 7;
		linkElement1.y = stationElement1.city.y + 15;
		linkElement1.setVerticalCorrection();
		linkElement1.shadowPos = linkElement1.shRight;
		linkElement1.visible = true;
		stationElement1.connectedLinks = [linkElement1];

		stationElement2.stationId = 6270;
		stationElement2.stationName = "Leeuwarden";
		stationElement2.city.anchors.topMargin = -(166+9+54+7);
		stationElement2.city.anchors.leftMargin = -(155+17+90);
		stationElement2.button.anchors.top = stationElement2.bottom;
		stationElement2.button.anchors.topMargin = -(166+9+54);
		stationElement2.button.anchors.leftMargin = -155;
		stationElement2.button.text = qsTr("Leeuwarden");
		stationElement2.visible = true;
		stationElement2.button.topClickMargin = 5;
		stationElement2.button.bottomClickMargin = 8;
		linkElement2.width = (90) - stationElement2.city.width;
		linkElement2.x = stationElement2.city.x + 15;
		linkElement2.y = stationElement2.city.y + 7;
		linkElement2.setCorrection(-1, 0, 1, 0, -1, 0, 0, 0);
		linkElement2.visible = true;
		p.drawDiagonalLine(linkElement3, linkElement2.x + linkElement2.width, linkElement2.y, 17, p.diagonalDirection.rightDown);
		linkElement3.setCorrection(1, 0, 0, 0, 0, 0, 0, 0);
		stationElement2.connectedLinks = [linkElement2, linkElement3];

		stationElement3.stationId = 6267;
		stationElement3.stationName = "Stavoren";
		stationElement3.city.anchors.topMargin = -(166);
		stationElement3.city.anchors.leftMargin = -(155+17+90+44);
		stationElement3.button.anchors.top = stationElement3.bottom;
		stationElement3.button.anchors.topMargin = -(166+9);
		stationElement3.button.anchors.leftMargin = -155;
		stationElement3.button.bottomClickMargin = 10;
		stationElement3.button.topClickMargin = 10;
		stationElement3.button.text = "Stavoren";
		stationElement3.visible = true;
		linkElement4.width = (44+90+17) - stationElement3.city.width;
		linkElement4.x = stationElement3.city.x + 15;
		linkElement4.y = stationElement3.city.y + 7;
		linkElement4.visible = true;
		stationElement3.connectedLinks = [linkElement4];

		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	function showUtrecht() {
		provinceImg.anchors.topMargin = 148;
		provinceImg.anchors.leftMargin = 390;

		stationElement0.stationId = 6260;
		stationElement0.stationName = "De Bilt";
		stationElement0.city.anchors.topMargin = -(121+14+58);
		stationElement0.city.anchors.leftMargin = -(147+163);
		stationElement0.button.anchors.top = stationElement0.bottom;
		stationElement0.button.anchors.topMargin = -(121+14+58+14);
		stationElement0.button.anchors.leftMargin = -147;
		stationElement0.button.bottomClickMargin = 10;
		stationElement0.button.topClickMargin = 10;
		stationElement0.button.text = "De Bilt";
		stationElement0.visible = true;
		linkElement0.width = (163) - stationElement0.city.width;
		linkElement0.x = stationElement0.city.x + 15;
		linkElement0.y = stationElement0.city.y + 7;
		linkElement0.visible = true;
		stationElement0.connectedLinks = [linkElement0];

		stationElement1.stationId = 6348;
		stationElement1.stationName = "Lopik-Cabauw";
		stationElement1.city.anchors.topMargin = -(121);
		stationElement1.city.anchors.leftMargin = -(147+163+72);
		stationElement1.button.anchors.top = stationElement1.bottom;
		stationElement1.button.anchors.topMargin = -(121+14);
		stationElement1.button.anchors.leftMargin = -147;
		stationElement1.button.bottomClickMargin = 10;
		stationElement1.button.topClickMargin = 10;
		stationElement1.button.text = "Lopik-Cabauw";
		stationElement1.visible = true;
		linkElement1.width = (72+163) - stationElement1.city.width;
		linkElement1.x = stationElement1.city.x + 15;
		linkElement1.y = stationElement1.city.y + 7;
		linkElement1.visible = true;
		stationElement1.connectedLinks = [linkElement1];

		stationElement2.visible = false;
		stationElement3.visible = false;
		stationElement4.visible = false;
		stationElement5.visible = false;
	}

	Image {
		id: provinceImg
		anchors.top: parent.top
		anchors.left: parent.left
	}

	BuienradarStationElement{
		id: stationElement0
		width: parent.width; height: parent.height;
		onStationClicked: p.stationSelected(0);
	}
	BuienradarStationElement{
		id: stationElement1
		width: parent.width; height: parent.height;
		onStationClicked: p.stationSelected(1);
	}
	BuienradarStationElement{
		id: stationElement2
		width: parent.width; height: parent.height;
		onStationClicked: p.stationSelected(2);
	}
	BuienradarStationElement{
		id: stationElement3
		width: parent.width; height: parent.height;
		onStationClicked: p.stationSelected(3);
	}
	BuienradarStationElement{
		id: stationElement4
		width: parent.width; height: parent.height;
		onStationClicked: p.stationSelected(4);
	}
	BuienradarStationElement{
		id: stationElement5
		width: parent.width; height: parent.height;
		onStationClicked: p.stationSelected(5);
	}

	LinkElement {id: linkElement0}
	LinkElement {id: linkElement1}
	LinkElement {id: linkElement2}
	LinkElement {id: linkElement3}
	LinkElement {id: linkElement4}
	LinkElement {id: linkElement5}
	LinkElement {id: linkElement6}
	LinkElement {id: linkElement7}
	LinkElement {id: linkElement8}
	LinkElement {id: linkElement9}
}
